@@ -61,12 +61,14 @@ void {fn_attributes} {ns}__drop({list_blob} *self_blob);
 {list_blob} {fn_attributes} {ns}__with_capacity(uint64_t capacity);
 {list_blob} {fn_attributes} {ns}__from_raw({item_blob} *ptr, uint64_t len);
 void {fn_attributes} {ns}__push({list_blob} *self_blob, {item_blob} item_blob);
+{item_blob} {fn_attributes} {ns}__pop({list_blob} *self_blob);
 {item_blob} {fn_attributes} {ns}__remove({list_blob} *self_blob, uint64_t index);
 void {fn_attributes} {ns}__shrink_to_fit({list_blob} *self_blob);
 const {item_blob} *{fn_attributes} {ns}__as_ptr(const {list_blob} *self_blob);
-{item_blob} *{fn_attributes} {ns}__into_ptr({list_blob} self_blob);
+{item_blob} *{fn_attributes} {ns}__take_ptr({list_blob} *self_blob);
 uint64_t {fn_attributes} {ns}__get_len(const {list_blob} *self_blob);
 uint64_t {fn_attributes} {ns}__get_capacity(const {list_blob} *self_blob);
+void {fn_attributes} {ns}__reserve({list_blob} *self_blob, uint64_t additional);
 ",
         ns = ns(subns),
         fn_attributes = fn_attributes,
