@@ -11,7 +11,8 @@ pub fn ptr(options: &Options) -> String {
 {ptr_blob} {fn_attributes} {ns}__new(void *ptr);
 void {fn_attributes} {ns}__of_node__drop({ptr_blob} *self_blob);
 void {fn_attributes} {ns}__of_token__drop({ptr_blob} *self_blob);
-void *{fn_attributes} {ns}__get_raw({ptr_blob} *self_blob);
+const void *{fn_attributes} {ns}__get_raw(const {ptr_blob} *self_blob);
+void *{fn_attributes} {ns}__into_raw({ptr_blob} self_blob);
 ",
         ns = ns(),
         fn_attributes = options.fn_attributes,
